--[[
The DuplicationPolicy has a chat cache for the last 10 messages (configurable).
The policy lookup that cache on every incoming message. If a duplication was found then
the message will be dropped.

A message who passed all policies will be applied to the cache on the train path.
]]

DuplicationPolicy = class();

-- Initializes a new DuplicationPolicy instance
function DuplicationPolicy:Constructor(filterData)
	self.Name = "DuplicationPolicy";
	self.Data = filterData;
end

-- Executes this policy
function DuplicationPolicy:Execute(message, channel, username, text, bag)
	for key, post in pairs(self.Data.ChatHistoryCache) do
		-- High frequently post (maybe Spam)
		if post == message then
			return true;
		end
	end
end

-- Train this policy
function DuplicationPolicy:Apply(message, channel, username, text, blocked, policyName, bag)
	if blocked == true then
		return;
	end

	-- remember the message
	self.Data.ChatHistoryIndex = (self.Data.ChatHistoryIndex + 1) % self.Data.ChatHistorySize;
	self.Data.ChatHistoryCache[self.Data.ChatHistoryIndex] = message;
end
